@@ -2,15 +2,17 @@ from .ast_node import ASTNode
 from .factor import Factor
 from .operator import Operator
 from .operator_resolver import OperatorResolver
+from .structured import Structured
 from .term import Term
 from .token import Token
 
 
 __all__ = [
-    'ASTNode',
-    'Factor',
-    'Operator',
-    'OperatorResolver',
-    'Term',
-    'Token'
+    "ASTNode",
+    "Factor",
+    "Operator",
+    "OperatorResolver",
+    "Structured",
+    "Term",
+    "Token",
 ]
