@@ -5,22 +5,21 @@ from formulaic.parser.types import Factor
 
 
 class TestScopedFactor:
-
     @pytest.fixture
     def scoped_factor(self):
-        return ScopedFactor(Factor('a'))
+        return ScopedFactor(Factor("a"))
 
     @pytest.fixture
     def scoped_factor_reduced(self):
-        return ScopedFactor(Factor('a'), reduced=True)
+        return ScopedFactor(Factor("a"), reduced=True)
 
     def test_repr(self, scoped_factor, scoped_factor_reduced):
-        assert repr(scoped_factor) == 'a'
-        assert repr(scoped_factor_reduced) == 'a-'
+        assert repr(scoped_factor) == "a"
+        assert repr(scoped_factor_reduced) == "a-"
 
     def test_hash(self, scoped_factor, scoped_factor_reduced):
-        assert hash(scoped_factor) == hash('a')
-        assert hash(scoped_factor_reduced) == hash('a-')
+        assert hash(scoped_factor) == hash("a")
+        assert hash(scoped_factor_reduced) == hash("a-")
 
     def test_equality(self, scoped_factor, scoped_factor_reduced):
         assert scoped_factor == scoped_factor
@@ -29,7 +28,7 @@ class TestScopedFactor:
 
     def test_sort(self, scoped_factor, scoped_factor_reduced):
         assert scoped_factor_reduced < scoped_factor
-        assert scoped_factor < ScopedFactor(Factor('b'))
+        assert scoped_factor < ScopedFactor(Factor("b"))
 
         with pytest.raises(TypeError):
             scoped_factor < 1
